module Products.Helpers exposing (..)

import Config.CardFormat exposing (..)
import Config.Colour exposing (..)
import Config.Format exposing (..)
import Config.StrengthBar exposing (..)
import Config.ToolTip exposing (..)
import Effect exposing (Effect)
import Element as E exposing (..)
import Element.Background as B exposing (..)
import Element.Border as D
import Element.Events exposing (onClick)
import Element.Font as F
import Headers.Types exposing (..)
import Html.Attributes as H exposing (style)
import Interviews.Types exposing (..)
import Layouts
import Page exposing (Page)
import Products.Types exposing (..)
import Route exposing (Route)
import Shared
import View exposing (View)


nutriDexMaker : NutriDex -> Element msg
nutriDexMaker nutridex =
    row
        topLevelBox
        [ column
            [ E.width <| px 785
            , D.width 5
            , D.color colourTheme.backgroundDarkGrey
            , D.roundEach
                { topLeft = 32
                , topRight = 32
                , bottomRight = 32
                , bottomLeft = 32
                }
            ]
            [ paragraph
                (nonHighlightedTitleFormat
                    ++ [ F.size 20
                       , B.color colourTheme.textDarkOrange
                       , paddingEach
                            { top = 6
                            , bottom = 3
                            , left = 25
                            , right = 15
                            }
                       , width fill
                       , F.center
                       , D.roundEach
                            { topLeft = 26
                            , topRight = 26
                            , bottomRight = 0
                            , bottomLeft = 0
                            }
                       ]
                )
                [ text nutridex.nutriDexTitle ]
            , cardFormatter
                [ cardContentSpacing
                    [ column
                        fieldSpacer
                        [ paragraph
                            (paragraphFormat
                                ++ [ F.size 18
                                   , F.center
                                   ]
                            )
                            [ featureList nutridex ]
                        ]
                    ]
                ]
            ]
        ]


makeFeature : Features -> Element msg
makeFeature features =
    column
        [ E.width fill
        , paddingEach
            { top = 0
            , right = 0
            , bottom = 0
            , left = 8
            }
        ]
        [ row [ E.width fill ]
            [ column [ E.width fill ]
                [ paragraph [ F.regular, F.alignLeft ]
                    [ text ("‣ " ++ features.feature) ]
                ]
            ]
        ]


featureList : NutriDex -> Element msg
featureList nutridex =
    column
        [ spacing 8
        , width fill
        , height fill
        ]
        [ row
            [ spacing 20
            , width fill
            , height fill
            ]
            [ column
                []
                [ column
                    [ spacing 20
                    ]
                    [ row
                        [ D.rounded 25
                        , D.width 5
                        , centerX
                        , D.color colourTheme.backgroundLightGrey
                        , B.color colourTheme.backgroundLightGrey
                        ]
                        [ E.image
                            [ D.rounded 20
                            , clip
                            , E.width <| px 305
                            , E.height <| px 231
                            ]
                            { src = "nutridex/nutridex.png", description = "" }
                        ]
                    , row
                        [ D.width 5
                        , D.rounded 25
                        , centerX
                        , D.color colourTheme.backgroundLightGrey
                        , B.color colourTheme.backgroundLightGrey
                        ]
                        [ row
                            [ B.color colourTheme.textDarkOrange
                            , D.rounded 30
                            , F.size 25
                            , F.bold
                            , paddingEach
                                { top = 10
                                , right = 25
                                , bottom = 10
                                , left = 25
                                }
                            ]
                            [ newTabLink []
                                { url = "https://the-nutrivore.myshopify.com/cart/31192710807615:1?channel=buy_button"
                                , label = row [ F.center ] [ text "Purchase!" ]
                                }
                            ]
                        ]
                    ]
                , column
                    [ centerX ]
                    [ column
                        [ F.size 18
                        , F.bold
                        , F.color colourTheme.textLightOrange
                        ]
                        [ newTabLink []
                            { url = "https://drive.google.com/file/d/1sk7VgjuL2rEqQdnBRdZjr2_Ab9vwrbmo/view?usp=sharing"
                            , label =
                                paragraph
                                    [ centerX
                                    , centerY
                                    ]
                                    [ text "Cost Efficiency Score!" ]
                            }
                        ]
                    ]
                ]
            , column [ width fill, F.size 12, spacing 3 ] <|
                List.map2 (\x y -> makeFeature x)
                    nutridex.nutriDexFeatures
                    (List.range 1 (List.length nutridex.nutriDexFeatures))
            ]
        ]
